pub fn check_hash_operator_class<T>() -> PluginResult<()>Expand description
Hash classes never select a hash algorithm or physical token. Their law is exactly the external type equality/hash-component contract.
pub fn check_hash_operator_class<T>() -> PluginResult<()>Hash classes never select a hash algorithm or physical token. Their law is exactly the external type equality/hash-component contract.