OperatorClassKey

Trait OperatorClassKey 

pub trait OperatorClassKey {
    // Required method
    fn key_compare(&self, other: &Self) -> Ordering;
}
Core scalar ordering used to prove that an operator-class key encoder preserves the semantic relation declared by its external input type.

Required Methods

fn key_compare(&self, other: &Self) -> Ordering

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl OperatorClassKey for bool

Source

fn key_compare(&self, other: &Self) -> Ordering

Source

impl OperatorClassKey for f32

Source

fn key_compare(&self, other: &Self) -> Ordering

Source

impl OperatorClassKey for f64

Source

fn key_compare(&self, other: &Self) -> Ordering

Source

impl OperatorClassKey for i8

Source

fn key_compare(&self, other: &Self) -> Ordering

Source

impl OperatorClassKey for i16

Source

fn key_compare(&self, other: &Self) -> Ordering

Source

impl OperatorClassKey for i32

Source

fn key_compare(&self, other: &Self) -> Ordering

Source

impl OperatorClassKey for i64

Source

fn key_compare(&self, other: &Self) -> Ordering

Source

impl OperatorClassKey for u8

Source

fn key_compare(&self, other: &Self) -> Ordering

Source

impl OperatorClassKey for u16

Source

fn key_compare(&self, other: &Self) -> Ordering

Source

impl OperatorClassKey for u32

Source

fn key_compare(&self, other: &Self) -> Ordering

Source

impl OperatorClassKey for u64

Source

fn key_compare(&self, other: &Self) -> Ordering

Implementors

Source

impl<const MAX: usize> OperatorClassKey for BoundedBytes<MAX>

Source

impl<const MAX: usize> OperatorClassKey for BoundedText<MAX>