pub trait OperatorClassKey {
// Required method
fn key_compare(&self, other: &Self) -> Ordering;
}Expand description
Core scalar ordering used to prove that an operator-class key encoder preserves the semantic relation declared by its external input type.
Required Methods
fn key_compare(&self, other: &Self) -> Ordering
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".